@@ -63,14 +63,13 @@ DccManager::DccManager(QObject *parent)
 
     initConfig();
     connect(m_plugins, &PluginManager::addObject, this, &DccManager::addObject, Qt::QueuedConnection);
-    connect(qApp, &QCoreApplication::aboutToQuit, this, &DccManager::onQuit);
     waitShowPage("system", QDBusMessage());
 }
 
 DccManager::~DccManager()
 {
     qCDebug(dccLog()) << "delete dccManger";
-    onQuit();
+    clearData();
     delete m_plugins;
     qCDebug(dccLog()) << "delete dccManger end";
 }
@@ -123,13 +122,13 @@ void DccManager::loadModules(bool async, const QStringList &dirs)
 int DccManager::width() const
 {
     auto w = m_dconfig->value(WidthConfig).toInt();
-    return w > 780 ? w : 780;
+    return w > 520 ? w : 780;
 }
 
 int DccManager::height() const
 {
     auto h = m_dconfig->value(HeightConfig).toInt();
-    return h > 530 ? h : 530;
+    return h > 400 ? h : 530;
 }
 
 DccApp::UosEdition DccManager::uosEdition() const
@@ -725,7 +724,7 @@ bool DccManager::removeObjectFromParent(DccObject *obj)
     return false;
 }
 
-void DccManager::onQuit()
+void DccManager::clearData()
 {
     if (m_plugins->isDeleting()) {
         return;
